%global __provides_exclude perl\\(BackupPC::.*\\)
%global __requires_exclude perl\\(BackupPC::.*\\)

%define upstream_name BackupPC

Name:           backuppc
Version:        4.4.0
Release:        %mkrel 2
Summary:        High-performance, enterprise-grade backup system
Group:          Archiving/Backup
License:        GPLv2
Url:            https://backuppc.github.io/backuppc/
Source:         https://github.com/backuppc/backuppc/releases/download/%version/%{upstream_name}-%{version}.tar.gz
Source1:        BackupPC_Admin.c
Source2:        backuppc.service
Source3:        backuppc.tmpfiles
Source4:        backuppc.httpd
BuildRequires:  perl(BackupPC::XS) >= 0.620.0
BuildRequires:  perl(CGI)
BuildRequires:  perl(Compress::Zlib)
BuildRequires:  perl(Digest::MD5)
BuildRequires:  perl(File::Listing)
Requires:       sendmail-command
Requires:       apache
Requires:       rsync-bpc
Requires:       perl(Net::FTP::AutoReconnect)
Requires:       perl(Net::FTP::RetrHandle)
Requires:       perl(BackupPC::XS)
Requires(post):     rpm-helper >= 0.24.8-1
Requires(preun):    rpm-helper >= 0.24.8-1
Recommends:         openssh-clients
Recommends:         samba-client

%description
BackupPC is a high-performance, enterprise-grade system
for backing up Linux, Win32, and laptops to a server's disk.
Features include clever pooling of identical files, no client-side
software, and a powerful Apache/CGI user interface.

%prep
%setup -q -n %{upstream_name}-%{version}

cp %{SOURCE1} .

# attempt to unbundle as much as possible
for m in Net/FTP; do
  rm -rf lib/$m
  sed -i "\@lib/$m@d" configure.pl 
done

%build
gcc -o BackupPC_Admin BackupPC_Admin.c %{optflags}

%install
%{__perl} configure.pl \
    --batch \
    --backuppc-user=backuppc \
    --dest-dir %{buildroot} \
    --config-dir %{_sysconfdir}/%{name}/ \
    --config-override CgiURL=\"http://localhost/%{name}\" \
    --config-override ClientNameAlias=undef \
    --config-override NmbLookupPath=\"%{_bindir}/nmblookup\" \
    --config-override ParPath=\"%{_bindir}/par2\" \
    --config-override PingPath=\"%{_bindir}/ping\" \
    --config-override Ping6Path=\"%{_sbindir}/ping6\" \
    --config-override RrdToolPath=\"%{_bindir}/rrdtool\" \
    --config-override RsyncBackupPCPath=\"%{_bindir}/rsync_bpc\" \
    --config-override RsyncClientPath=\"%{_bindir}/rsync\" \
    --config-override SendmailPath=\"%{_sbindir}/sendmail\" \
    --config-override SmbClientPath=\"%{_bindir}/smbclient\" \
    --config-override SshPath=\"%{_bindir}/ssh\" \
    --config-override TarClientPath=\"%{_bindir}/gtar\" \
    --config-override XferMethod=\"rsync\" \
    --cgi-dir %{_libexecdir}/%{name} \
    --data-dir %{_localstatedir}/lib/%{name}/ \
    --hostname localhost \
    --html-dir %{_datadir}/%{name}/html/ \
    --html-dir-url /%{name}/images \
    --install-dir %{_datadir}/%{name} \
    --log-dir %{_localstatedir}/log/%{name} \
    --no-set-perms \
    --uid-ignore

chmod +x %{buildroot}%{_datadir}/%{name}/bin/*
chmod +x %{buildroot}%{_libexecdir}/%{name}/BackupPC_Admin

# systemd
install -D -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service

# tmpfiles
install -D -m 0644 %{SOURCE3} %{buildroot}%{_tmpfilesdir}/%{name}.conf

# apache configuration
install -D -m 0644 %{SOURCE4} %{buildroot}%{_webappconfdir}/%{name}.conf

# logs
install -d -m 755 %{buildroot}%{_localstatedir}/log/%{name}

# perl-suidperl is no longer avaialable, use a C wrapper
mkdir -p %{buildroot}%{_datadir}/%{name}/sbin
mv %{buildroot}%{_libexecdir}/%{name}/BackupPC_Admin \
   %{buildroot}%{_datadir}/%{name}/sbin/BackupPC_Admin
install -pm 0755 BackupPC_Admin %{buildroot}%{_libexecdir}/%{name}/

# remove useless files
rm -f %{buildroot}%{_sysconfdir}/%{name}/*.sample

%pre
%_pre_useradd %{name} %{_localstatedir}/lib/%{name} /bin/sh

%post
%_tmpfilescreate %{name}
%_post_service %{name}

%preun
%_preun_service %{name}
if [ $1 -ne 0 ] ; then
# previous releases of backuppc had root as the owner - undo this fault
  chown backuppc:backuppc %{_sysconfdir}/%{name}
fi

%postun
%_postun_userdel %{name}

%files
%doc ChangeLog README.md LICENSE doc/*
# backuppc must be able to edit the config file and create backup files
%dir %attr(-,backuppc,backuppc) %{_sysconfdir}/%{name}
%config(noreplace) %attr(-,backuppc,apache) %{_sysconfdir}/%{name}/*
%config(noreplace) %{_webappconfdir}/%{name}.conf
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf
%{_datadir}/%{name}
%dir %attr(-,backuppc,backuppc) %{_localstatedir}/log/%{name}
%dir %attr(-,backuppc,backuppc) %{_localstatedir}/lib/%{name}
%attr(4750,backuppc,apache) %{_libexecdir}/%{name}/BackupPC_Admin


%changelog
* Mon Feb 01 2021 neoclust <neoclust> 4.4.0-2.mga8
+ Revision: 1674398
- Fix path in tmpfiles.d/ file

* Tue Jul 07 2020 wally <wally> 4.4.0-1.mga8
+ Revision: 1602855
- new version 4.4.0 (mga#26911)

* Fri Feb 14 2020 umeabot <umeabot> 4.3.0-2.mga8
+ Revision: 1521253
- Mageia 8 Mass Rebuild

* Mon Dec 17 2018 shlomif <shlomif> 4.3.0-1.mga7
+ Revision: 1342288
- New version 4.3.0 (mga#24010)

* Sat Dec 15 2018 daviddavid <daviddavid> 4.1.3-3.mga7
+ Revision: 1341435
- add missing dependency on perl-BackupPC-XS (mga#24010)

* Fri Sep 21 2018 umeabot <umeabot> 4.1.3-2.mga7
+ Revision: 1295253
- Mageia 7 Mass Rebuild

* Mon Sep 18 2017 guillomovitch <guillomovitch> 4.1.3-1.mga7
+ Revision: 1155275
- new version 4.1.3
- use upstream installation procedure

* Sun Feb 05 2017 shlomif <shlomif> 3.3.2-1.mga6
+ Revision: 1084862
- New version 3.3.2 that should include fix for MGA#18251 .

* Wed Feb 10 2016 umeabot <umeabot> 3.3.1-2.mga6
+ Revision: 953244
- Mageia 6 Mass Rebuild

* Sun Aug 16 2015 ycantin <ycantin> 3.3.1-1.mga6
+ Revision: 865155
- fix more spec formatting
- fix spec formatting
- new version 3.3.1

* Wed Oct 15 2014 umeabot <umeabot> 3.3.0-5.mga5
+ Revision: 745447
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.3.0-4.mga5
+ Revision: 678099
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes
- s/uggests:/Recommends:/

* Sat Jul 12 2014 doktor5000 <doktor5000> 3.3.0-3.mga5
+ Revision: 651416
+ rebuild (emptylog)

* Sat Oct 19 2013 umeabot <umeabot> 3.3.0-2.mga4
+ Revision: 535126
- Mageia 4 Mass Rebuild

* Wed Sep 18 2013 juergen_harms <juergen_harms> 3.3.0-1.mga4
+ Revision: 481173
- Upgrade to new upstream release
- Remove obsolete patches

* Sun Mar 24 2013 colin <colin> 3.2.1-11.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Fri Jan 11 2013 umeabot <umeabot> 3.2.1-10.mga3
+ Revision: 346830
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Nov 25 2012 colin <colin> 3.2.1-9.mga3
+ Revision: 321761
- Do not package tmpfiles conf in /etc
- Run systemd-tmpfiles --create on post install

* Sat Sep 08 2012 guillomovitch <guillomovitch> 3.2.1-8.mga3
+ Revision: 290478
- make webapp configuration file compatible with apache 2.4
+ juergen_harms <juergen_harms>
- Add / correct variable definitions in config.pl (bugzilla 6530):
  SshPath, SmbClientPath, NmbLookupPath, TarClientPath, TopDir

* Thu Jun 07 2012 juergen_harms <juergen_harms> 3.2.1-6.mga3
+ Revision: 257000
- Add patches for CVE-2011-5081 and 4923

* Wed May 09 2012 pterjan <pterjan> 3.2.1-5.mga2
+ Revision: 234949
- Fix initscript's LSB header
- Fix License tag

* Sat Apr 28 2012 tmb <tmb> 3.2.1-4.mga2
+ Revision: 233603
- Require rpm-helper >= 0.24.8-1 for systemd support

* Fri Apr 27 2012 tmb <tmb> 3.2.1-3.mga2
+ Revision: 233503
- rebuild for versioned rpm-helper requires

* Sun Apr 22 2012 guillomovitch <guillomovitch> 3.2.1-2.mga2
+ Revision: 232584
- systemd support

* Sun Dec 04 2011 juergen_harms <juergen_harms> 3.2.1-1.3.mga2
+ Revision: 176052
- Restore userdel in postun (needed for build to succeed)
- Change ownership of backuppc.config to backupc:backuppc
- Remove %%_postun_userdel : the user "backuppc" must survive urpme backuppc
- Correct upstream perl syntax (patch2) to avoid throwing error messages
  at service start
- Add info to README.mga: user "backuppc" and backup-data

* Tue Nov 22 2011 juergen_harms <juergen_harms> 3.2.1-1.2.mga2
+ Revision: 170886
- Correct handling change of ownership (/etc/backuppc) in %%preun

* Tue Nov 22 2011 juergen_harms <juergen_harms> 3.2.1-1.1.mga2
+ Revision: 170847
- Tidy %%files section (avoid "listed twice" warnings for...BackupPC... files )
- Fix: "Edit Config" and "Edit Hosts" did not work from CGI interface:
  owner of /etc/backupc (and files) must be backuppc

* Fri Nov 18 2011 juergen_harms <juergen_harms> 3.2.1-1.mga2
+ Revision: 168885
- Import BackupPC-3.2.1 from upstream
- Drop xss.patch (it had fixed buzilla #2736 - upstream 3.2.1 contains that fix)
- Modify README.mdv: mdv -> mga; add recommendation on lighttpd server
  definition; improve wording.

* Wed Oct 26 2011 juergen_harms <juergen_harms> 3.2.0-4.2.mga2
+ Revision: 158224
- add backuppc-3.2.0-xss.patch to SOURCES
- rename xss.patch
- fix bugzilla #2736 (XSS problem : http://www.openwall.com/lists/oss-security/2011/0...)
- fix apache server definition (buzilla #600)
- correct cgi permissions (bugzilla #600)
- fix source URL

* Tue Sep 13 2011 boklm <boklm> 3.2.0-4.mga2
+ Revision: 143025
- fix lsb comment block

* Tue Apr 05 2011 ennael <ennael> 3.2.0-3.mga1
+ Revision: 80636
- clean spec file
- fix arch

* Sun Apr 03 2011 ennael <ennael> 3.2.0-2.mga1
+ Revision: 80229
- fix #600 (The http user-interface to backuppc does not work):
  use Debian wrapper

* Fri Mar 04 2011 ennael <ennael> 3.2.0-1.mga1
+ Revision: 64332
- clean spec file
- imported package backuppc


* Sat Aug 07 2010 Guillaume Rousse <guillomovitch@mandriva.org> 3.2.0-1mdv2011.0
+ Revision: 567315
- new version

* Mon Mar 01 2010 Guillaume Rousse <guillomovitch@mandriva.org> 3.1.0-10mdv2010.1
+ Revision: 513151
- rely on filetrigger for reloading apache configuration begining with 2010.1, rpm-helper macros otherwise

* Thu Oct 01 2009 Oden Eriksson <oeriksson@mandriva.com> 3.1.0-9mdv2010.0
+ Revision: 452219
- P1: security fix for CVE-2009-3369 (debian)

* Thu Sep 10 2009 Thierry Vignaud <tv@mandriva.org> 3.1.0-8mdv2010.0
+ Revision: 436764
- rebuild

* Thu Jan 29 2009 Guillaume Rousse <guillomovitch@mandriva.org> 3.1.0-7mdv2009.1
+ Revision: 335370
- ship missing javascript file (close #47365)

* Mon Jan 19 2009 Guillaume Rousse <guillomovitch@mandriva.org> 3.1.0-6mdv2009.1
+ Revision: 331458
- add a few soft dependencies, as nobody want to read documentation (fix #47045)

* Wed Jul 23 2008 Thierry Vignaud <tv@mandriva.org> 3.1.0-5mdv2009.0
+ Revision: 243159
- rebuild

  + Pixel <pixel@mandriva.com>
    - adapt to %%_localstatedir now being /var instead of /var/lib (#22312)

* Sun Feb 17 2008 Guillaume Rousse <guillomovitch@mandriva.org> 3.1.0-3mdv2008.1
+ Revision: 170040
- fix FHS patch (fix #37746)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Nov 29 2007 Guillaume Rousse <guillomovitch@mandriva.org> 3.1.0-2mdv2008.1
+ Revision: 113947
- don't provide or require private libfs

* Thu Nov 29 2007 Guillaume Rousse <guillomovitch@mandriva.org> 3.1.0-1mdv2008.1
+ Revision: 113946
- new version

* Sun Aug 19 2007 Guillaume Rousse <guillomovitch@mandriva.org> 3.0.0-2mdv2008.0
+ Revision: 66810
- set path for as much command as possible in default configuration (fix #32036)


* Wed Feb 28 2007 Guillaume Rousse <guillomovitch@mandriva.org> 3.0.0-1mdv2007.0
+ Revision: 130153
- sync sources
- new version
  rediff FHS patch
  unify service script

* Wed Feb 14 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.1.2.2-3mdv2007.1
+ Revision: 120838
- LSB-compatible init script

* Fri Dec 15 2006 Guillaume Rousse <guillomovitch@mandriva.org> 2.1.2.2-2mdv2007.1
+ Revision: 97306
- move documentation under %%datadir/backuppc, as it is accessed at runtime (fix #27594)
  no need to modify main cgi file name
- Import backuppc

* Wed Aug 02 2006 Guillaume Rousse <guillomovitch@mandriva.org> 2.1.2.2-1mdv2007.0
- new version
- new webapps macros
- use herein document for README.mdv

* Wed Dec 21 2005 Guillaume Rousse <guillomovitch@zarb.org> 2.1.2-1mdk
- initial mdk package

